django_analyses.serializers.input.types package — django_analyses 0.0.3 documentation

# django_analyses.serializers.input.types package

## Submodules

## django_analyses.serializers.input.types.boolean_input module

class `django_analyses.serializers.input.types.boolean_input.` `BooleanInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.boolean_input.BooleanInput`

## django_analyses.serializers.input.types.directory_input module

class `django_analyses.serializers.input.types.directory_input.` `DirectoryInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.directory_input.DirectoryInput`

## django_analyses.serializers.input.types.file_input module

class `django_analyses.serializers.input.types.file_input.` `FileInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.file_input.FileInput`

## django_analyses.serializers.input.types.float_input module

class `django_analyses.serializers.input.types.float_input.` `FloatInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.float_input.FloatInput`

## django_analyses.serializers.input.types.integer_input module

class `django_analyses.serializers.input.types.integer_input.` `IntegerInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.integer_input.IntegerInput`

## django_analyses.serializers.input.types.list_input module

class `django_analyses.serializers.input.types.list_input.` `ListInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.list_input.ListInput`

## django_analyses.serializers.input.types.string_input module

class `django_analyses.serializers.input.types.string_input.` `StringInputSerializer`(instance=None, data=<class 'rest_framework.fields.empty'>, **kwargs)

  Bases: `rest_framework.serializers.ModelSerializer`

  class `Meta`

    Bases: `object`

    `fields` = ('id', 'key', 'value', 'run', 'definition')
    `model`

      alias of `django_analyses.models.input.types.string_input.StringInput`

## Module contents